@@ -34,7 +34,9 @@ class Device_Insteon_Dimmer(Device_Dimmer, Device_Insteon_Base):
             # print ('device {}. changed local control {}'.format(self.name,event.action))
 
     def set_level(self, level):
-        path = "nodes/" + self.address + "/cmd/DON/" + str(int(level / 100 * 255))
+        percentage = int(level / 100 * 255)
+        Device_Dimmer.set_level(self,level)
+        path = "nodes/" + self.address + "/cmd/DON/" + str(percentage)
         return self.send_request(path)
 
     # def fade_up(self):
